@@ -391,11 +391,11 @@ class QueenbeeTask(luigi.Task):
                 progress['total'] += 1
             else:
                 # task finished
-                if progress['running'] > 0:
+                if progress['running'] < 0:
                     # apparently this can happen is complicated workflows.
                     # I can spend hours to replicate and fix this issue but it is not
                     # really critical. This small fix will make it look reasonable.
-                    progress['running'] -= 1
+                    progress['running'] = 0
                 progress['completed'] += 1
 
             # write the json file
